@@ -1,20 +1,18 @@
 # encoding: utf8
 
-'''
+"""
 Created on 2014.06.23
 
 @author: Allen
-'''
+"""
+
 
 class Process(object):
-    
-    
     def __init__(self):
         pass
-    
+
     def start(self):
+        pass
+
+    def run(self, **kwargs):
         raise NotImplementedError
-    
-    def run(self, **kwargvs):
-        raise NotImplementedError
-    
