@@ -1,13 +1,13 @@
 # encoding: utf-8
 
-'''
+"""
 Created on 2014.04.21
 
 @author: Allen
-'''
+"""
 import os
 
-COMMAND_MODEULE = 'startpro.core.commands'
+COMMAND_MODULE = 'startpro.core.commands'
 
 SCRIPT_MODULE = ''
 
@@ -36,4 +36,8 @@ TEMPLATE_PACKAGE = os.path.join(TEMPLATE, "package.py")
 # LOAD PATHS
 LOAD_PATHS = '#LOAD_PATHS#'
 
+# TAMP FILE
+SCRIPT_TEMP = '.scripts.tmp'
 
+# LOAD FLAG
+HAS_LOAD = False
