@@ -1,27 +1,25 @@
 # encoding: utf-8
 
-'''
+"""
 Created on 2014.04.21
 
 @author: Allen
-'''
+"""
 
-class TopCommand():
-    '''
-    classdocs
-    '''
+
+class TopCommand(object):
 
     def __init__(self):
-        '''
+        """
         Constructor
-        '''
+        """
         pass
-        
-    def run(self, **kwargvs):
+
+    def run(self, **kwargs):
         raise NotImplementedError
-    
-    def help(self, **kwargvs):
-        '''
+
+    def help(self, **kwargs):
+        """
         print help info.
-        '''
-        pass
\ No newline at end of file
+        """
+        pass
